### Load as corpus button

Select the files to be loaded above and click the **Load as corpus** button to load them. Files can be loaded one or multiple at a time. Corpus files are required to build a corpus.

Corpus files are those files that contain the _document data_ (the text to be analysed). Corpus files may additionally contain metadata.

### Load as metadata button

Select the files to be loaded above and click the **Load as metadata** button to load them. Files can be loaded one or multiple at a time. Metadata files are not required to build a corpus as they are an optional way to load additional metadata.

Metadata files contain additional metadata (descriptive data about the text). By loading these files, they will need to be linked to the corpus files in the next step.

**Note:** this does not build the corpus. The **Build corpus** button will appear after loading.